RcuIntrusiveList

Struct RcuIntrusiveList 

pub struct RcuIntrusiveList<T, A: RcuListAdapter<T>> { /* private fields */ }

Implementations

Source

impl<T, A: RcuListAdapter<T>> RcuIntrusiveList<T, A>

pub unsafe fn push_front<'a>( &self, scope: &'a RcuReadScope, data: RcuPtrRef<'a, T>, )

Pushes a new element to the front of the list.

Safety

Requires external synchronization to exclude concurrent writers.

pub unsafe fn push_back<'a>(&self, scope: &RcuReadScope, data: RcuPtrRef<'a, T>)

Pushes a new element to the back of the list.

Safety

Requires external synchronization to exclude concurrent writers.

pub unsafe fn append(&self, scope: &RcuReadScope, other: Self)

Appends another list to the end of this list.

Safety

Requires external synchronization to exclude concurrent writers.

pub unsafe fn remove<'a>( &self, scope: &'a RcuReadScope, node: RcuPtrRef<'a, T>, ) -> RcuPtrRef<'a, Link>

Removes the given node from the list.

Returns the link of the next node in the list, if any.

Safety

Requires external synchronization to exclude concurrent writers.

pub unsafe fn split_off(&self, scope: &RcuReadScope, pos: usize) -> Self

Splits the list into two lists at the given position.

If the given position is past the end of the list, returns an empty list.

Safety

Requires external synchronization to exclude concurrent writers.

pub unsafe fn update(&self, scope: &RcuReadScope, other: Self)

Updates the list with the contents of another list.

Safety

Requires external synchronization to exclude concurrent writers.

pub unsafe fn clear<'a>( &self, scope: &'a RcuReadScope, callback: impl Fn(RcuPtrRef<'a, T>), )
where T: 'static,

Removes all elements from the list.

The callback is called for each element in the list. The caller is responsible for cleaning up the removed elements.

Concurrent readers may continue to see the old value of the list until the RCU state machine has made sufficient progress to ensure that no concurrent readers are holding read guards.

Safety

Requires external synchronization to exclude concurrent writers.

pub fn cursor<'a>( &'a self, scope: &'a RcuReadScope, ) -> RcuIntrusiveListCursor<'a, T, A>

Returns a cursor that can be used to traverse and modify the list.

Concurrent readers may continue to see the old value of the list until the RCU state machine has made sufficient progress to ensure that no concurrent readers are holding read guards.

pub fn iter<'a>(&self, scope: &'a RcuReadScope) -> impl Iterator<Item = &'a T>
where T: 'static,

Returns an iterator over the elements in the list.