RcuIntrusiveListCursor

Struct RcuIntrusiveListCursor 

pub struct RcuIntrusiveListCursor<'a, T, A: RcuListAdapter<T>> { /* private fields */ }
A cursor for traversing and modifying an RcuList.

See RcuList::cursor for more information.

Implementations

Source

impl<'a, T, A: RcuListAdapter<T>> RcuIntrusiveListCursor<'a, T, A>

pub fn current(&self) -> Option<&'a T>

Returns the element at the current cursor position.

pub fn advance(&mut self)

Advances the cursor to the next element in the list.

pub unsafe fn remove(&mut self) -> RcuPtrRef<'a, T>

Removes the element at the current cursor position.

After calling remove, the cursor will be positioned at the next element in the list.

Returns a pointer to the removed element. The caller is responsible for cleaning up the removed element.

Concurrent readers may continue to see this entry in the list until the RCU state machine has made sufficient progress to ensure that no concurrent readers are holding read guards.

Safety

Requires external synchronization to exclude concurrent writers.