RcuListCursor

Struct RcuListCursor 

pub struct RcuListCursor<'a, T: Send + Sync + 'static, A: RcuListAdapter<T>> { /* private fields */ }

Implementations

Source

impl<'a, T: Send + Sync + 'static, A: RcuListAdapter<T>> RcuListCursor<'a, T, A>

pub fn current(&self) -> Option<&T>

Returns the element at the current cursor position.

pub fn advance(&mut self)

Advances the cursor to the next element in the list.

pub unsafe fn remove(&mut self) -> RcuPtrRef<'a, T>

Removes the element at the current cursor position.

After calling remove, the cursor will be positioned at the next element in the list.

Concurrent readers may continue to see this entry in the list until the RCU state machine has made sufficient progress to ensure that no concurrent readers are holding read guards.

Safety

Requires external synchronization to exclude concurrent writers.