pub enum InsertionResult<V> {
Inserted(usize),
Updated(V),
}Expand description
The result of inserting an entry into the map.
Variants
Inserted(usize)
The entry was inserted.
The number of entries in the map is returned.
Updated(V)
The entry was updated.
The old value is returned.