pub struct RcuIntrusiveListCursor<'a, T, A: RcuListAdapter<T>> { /* private fields */ }Expand description
A cursor for traversing and modifying an RcuList.
See RcuList::cursor for more information.
Implementations
Sourceimpl<'a, T, A: RcuListAdapter<T>> RcuIntrusiveListCursor<'a, T, A>
impl<'a, T, A: RcuListAdapter<T>> RcuIntrusiveListCursor<'a, T, A>
Sourcepub unsafe fn remove(&mut self) -> RcuPtrRef<'a, T>
pub unsafe fn remove(&mut self) -> RcuPtrRef<'a, T>
Removes the element at the current cursor position.
After calling remove, the cursor will be positioned at the next element in the list.
Returns a pointer to the removed element. The caller is responsible for cleaning up the removed element.
Concurrent readers may continue to see this entry in the list until the RCU state machine has made sufficient progress to ensure that no concurrent readers are holding read guards.
Safety
Requires external synchronization to exclude concurrent writers.