RcuListAdapter

Trait RcuListAdapter 

pub trait RcuListAdapter<T> {
    // Required methods
    fn to_link(node: RcuPtrRef<'_, T>) -> RcuPtrRef<'_, Link>;
    fn from_link(link: RcuPtrRef<'_, Link>) -> RcuPtrRef<'_, T>;
}

Required Methods

Returns a pointer to the Link embedded in a Node.

Returns a pointer to the Node containing the given Link.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors