pub struct RcuListCursor<'a, T: Send + Sync + 'static, A: RcuListAdapter<T>> { /* private fields */ }Implementations
Sourceimpl<'a, T: Send + Sync + 'static, A: RcuListAdapter<T>> RcuListCursor<'a, T, A>
impl<'a, T: Send + Sync + 'static, A: RcuListAdapter<T>> RcuListCursor<'a, T, A>
Sourcepub unsafe fn remove(&mut self) -> RcuPtrRef<'a, T>
pub unsafe fn remove(&mut self) -> RcuPtrRef<'a, T>
Removes the element at the current cursor position.
After calling remove, the cursor will be positioned at the next element in the list.
Concurrent readers may continue to see this entry in the list until the RCU state machine has made sufficient progress to ensure that no concurrent readers are holding read guards.
Safety
Requires external synchronization to exclude concurrent writers.